@@ -6,9 +6,9 @@ use vars qw($VERSION $DEBUG @ISA @EXPORT @EXPORT_OK);
 require Exporter;
 
 @ISA = qw(Exporter);
-@EXPORT= qw( send_cm17 );
-@EXPORT_OK= qw();
-($VERSION) = q$Revision: 0.07 $ =~ /: (\S+)/; # Note: cvs version reset when we moved to sourceforge
+@EXPORT= qw();
+@EXPORT_OK= qw( send_cm17 );
+$VERSION = '0.06';
 $DEBUG = 0;
 
 #-----------------------------------------------------------------------------
@@ -45,7 +45,7 @@ sub send {
     
     my ($house, $code) = $house_code =~ /(\S)(\S+)/;
 
-    if (exists $main::config_parms{debug}) {
+    if (defined $main::config_parms{debug}) {
         $DEBUG = ($main::config_parms{debug} eq 'X10') ? 1 : 0;
     }
     print "CM17: $serial_port house=$house code=$code\n" if $DEBUG;
@@ -197,10 +197,11 @@ round to the next larger magnitude if not a multiple of 14%.
 
 =head1 EXPORTS
 
-The B<send_cm17> method is exported by default. It is identical to
-C<&ControlX10::CM17::send()>, and accepts the same parameters.
+Nothing is exported by default. A B<send_cm17> subroutine can be exported
+on request. It is identical to C<&ControlX10::CM17::send()>, and
+accepts the same parameters.
 
-  use ControlX10::CM17;
+  use ControlX10::CM17 qw( send_cm17 0.05 );
   send_cm17($serial_port, 'A1J');
 
 =head1 AUTHORS
@@ -210,23 +211,6 @@ Bruce Winter  bruce@misterhouse.net  http://misterhouse.net
 CPAN packaging by Bill Birthisel wcbirthisel@alum.mit.edu
 http://members.aol.com/bbirthisel
 
-=head2 MAILING LISTS
-
-General information about the mailing lists is at:
-
-  http://lists.sourceforge.net/mailman/listinfo/misterhouse-users
-  http://lists.sourceforge.net/mailman/listinfo/misterhouse-announce
-
-To post to this list, send your email to:
-
-  misterhouse-users@lists.sourceforge.net
-
-If you ever want to unsubscribe or change your options (eg, switch to
-or from digest mode, change your password, etc.), visit your
-subscription page at:
-
-  http://lists.sourceforge.net/mailman/options/misterhouse-users/$user_id
-
 =head1 SEE ALSO
 
 mh can be download from http://misterhouse.net
@@ -241,9 +225,9 @@ Win32::SerialPort and Device::SerialPort
 
 =head1 COPYRIGHT
 
-Copyright (C) 2000 Bruce Winter. All rights reserved.
+Copyright (C) 1999 Bruce Winter. All rights reserved.
 
 This module is free software; you can redistribute it and/or modify it
-under the same terms as Perl itself. 30 January 2000.
+under the same terms as Perl itself. 11 October 1999.
 
 =cut
